@@ -13,13 +13,13 @@ from typing import NewType, Union, Optional
 # from System.Collections.Generic import List as CSList
 # from System import Array, Double
 
-from .ParameterStructure.Values import SimMultiValueBigTable, SimMultiValueBigTableHeader, SimMultiValuePointer
-from .ParameterStructure.Instances import SimInstancePlacementGeometry, SimInstanceType
-from .ParameterStructure.Parameters import SimParameter
-from .ParameterStructure.Components import SimComponent, SimSlot, SimSlotBase, SimChildComponentEntry, ComponentUtils
-from .ParameterStructure.Algorithms.Components import ComponentManagement, ComponentMapping
-from .ParameterStructure.Assets import ContainedResourceFileEntry
-from .ParameterStructure.SimObjects import SimId
+from ParameterStructure.Values import SimMultiValueBigTable, SimMultiValueBigTableHeader, SimMultiValuePointer
+from ParameterStructure.Instances import SimInstancePlacementGeometry, SimInstanceType
+from ParameterStructure.Parameters import SimParameter
+from ParameterStructure.Components import SimComponent, SimSlot, SimSlotBase, SimChildComponentEntry, ComponentUtils
+from ParameterStructure.Algorithms.Components import ComponentManagement, ComponentMapping
+from ParameterStructure.Assets import ContainedResourceFileEntry
+from ParameterStructure.SimObjects import SimId
 
 from .config import continue_on_error
 from .utils import sort_references, sort_component_list, sort_slots, parse_slot
@@ -453,7 +453,7 @@ class SimultanObject(object, metaclass=MetaMock):
 
     @property
     def referenced_assets(self):
-        return [x.Resource for x in self._wrapped_obj.ReferencedAssets.Items.Items]
+        return [x.Resource for x in self._wrapped_obj.ReferencedAssets.Items]
 
     @lru_cache()
     def get_param_index(self, param: str) -> int:
@@ -525,6 +525,20 @@ class SimultanObject(object, metaclass=MetaMock):
     @slot_components.setter
     def slot_components(self, value):
         self._slot_components = value
+        
+    @property
+    def parent(self):
+        if not hasattr(self._wrapped_obj, 'Parent'):
+            return None
+
+        if self._wrapped_obj.Parent is not None:
+            return self._template_parser.create_python_object(self._wrapped_obj.Parent)
+        else:
+            return None
+
+    @property
+    def referenced_by(self):
+        return set([self._template_parser.create_python_object(x.Target) for x in self._wrapped_obj.ReferencedBy if not x.Target == self._wrapped_obj])
 
     def get_slot_components(self):
         """
@@ -864,6 +878,35 @@ class List(UserList):
         if self._wrapped_obj is not None:
             self._wrapped_obj.Name = value
 
+    @property
+    def parent(self):
+        if not hasattr(self._wrapped_obj, 'Parent'):
+            return None
+
+        if self._wrapped_obj.Parent is not None:
+            return self._template_parser.create_python_object(self._wrapped_obj.Parent)
+        else:
+            return None
+
+    @property
+    def current_slot(self):
+        return self._wrapped_obj.CurrentSlot
+
+    @current_slot.setter
+    def current_slot(self, value):
+        if isinstance(value, str):
+            value = SimSlotBase(value)
+        elif isinstance(value, SimSlotBase):
+            pass
+        else:
+            raise TypeError('Current slot must be of type str or SimSlotBase')
+        self._wrapped_obj.set_CurrentSlot(value)
+
+    @property
+    def referenced_by(self):
+        return set([self._template_parser.create_python_object(x.Target) for x in self._wrapped_obj.ReferencedBy if
+                    not x.Target == self._wrapped_obj])
+
 
 class ComponentList(UserList):
 
@@ -931,6 +974,35 @@ class ComponentList(UserList):
         if self._wrapped_obj is not None:
             self._wrapped_obj.Name = value
 
+    @property
+    def parent(self):
+        if not hasattr(self._wrapped_obj, 'Parent'):
+            return None
+
+        if self._wrapped_obj.Parent is not None:
+            return self._template_parser.create_python_object(self._wrapped_obj.Parent)
+        else:
+            return None
+
+    @property
+    def current_slot(self):
+        return self._wrapped_obj.CurrentSlot
+
+    @current_slot.setter
+    def current_slot(self, value):
+        if isinstance(value, str):
+            value = SimSlotBase(value)
+        elif isinstance(value, SimSlotBase):
+            pass
+        else:
+            raise TypeError('Current slot must be of type str or SimSlotBase')
+        self._wrapped_obj.set_CurrentSlot(value)
+
+    @property
+    def referenced_by(self):
+        return set([self._template_parser.create_python_object(x.Target) for x in self._wrapped_obj.ReferencedBy if
+                    not x.Target == self._wrapped_obj])
+
 
 class ReferenceList(UserList):
 
@@ -994,6 +1066,35 @@ class ReferenceList(UserList):
         if self._wrapped_obj is not None:
             self._wrapped_obj.Name = value
 
+    @property
+    def parent(self):
+        if not hasattr(self._wrapped_obj, 'Parent'):
+            return None
+
+        if self._wrapped_obj.Parent is not None:
+            return self._template_parser.create_python_object(self._wrapped_obj.Parent)
+        else:
+            return None
+
+    @property
+    def current_slot(self):
+        return self._wrapped_obj.CurrentSlot
+
+    @current_slot.setter
+    def current_slot(self, value):
+        if isinstance(value, str):
+            value = SimSlotBase(value)
+        elif isinstance(value, SimSlotBase):
+            pass
+        else:
+            raise TypeError('Current slot must be of type str or SimSlotBase')
+        self._wrapped_obj.set_CurrentSlot(value)
+
+    @property
+    def referenced_by(self):
+        return set([self._template_parser.create_python_object(x.Target) for x in self._wrapped_obj.ReferencedBy if
+                    not x.Target == self._wrapped_obj])
+
 
 class ValueField(pd.DataFrame):
 
