@@ -21,7 +21,7 @@ from functools import lru_cache
 
 from System.Linq import Enumerable
 from ParameterStructure.Values import SimMultiValuePointer
-from .ParameterStructure.Components import SimComponent
+from ParameterStructure.Components import SimComponent
 
 from typing import List as TypeList
 from typing import NewType, Union
